import React, { PropTypes } from 'react'
import styled from 'styled-components'
import theme from './theme'
import {
  withSpacing,
  withTextAlign,
  withFlex,
  withDisplay,
  withRounded,
  withPosition,
  withOverflow,
  withDimensions,
  withRotate,
  withBorders,
  withTruncate,
  withTextStyles,
  withTransform
} from '../enhancers'

const Styles = {}

Styles.clearfix = () => `
  &:before,
  &:after {
    display: table;
    clear: both;
    content: "";
  }
`

Styles.shadow = (val, theme) => {
  const i = Number.isInteger(val) ? val - 1 : 0
  return `
  box-shadow: ${theme.shadows[i]};
  `
}

const baseStyles = () =>`
  margin: 0;
  padding: 0;
  border: 0;
  font-size: 100%;
  line-height: 1
  font: inherit;
  vertical-align: baseline;
  -moz-osx-font-smoothing: grayscale;
  -webkit-font-smoothing: antialiased;
  font-smoothing: antialiased;
  font-family: ${theme.fonts.sans};
  font-size: ${theme.textStyles.body1.fontSize};
  font-weight: ${theme.textStyles.body1.fontWeight};
  letter-spacing: ${theme.textStyles.body1.letterSpacing};

  &, &:before, &:after {
    box-sizing: border-box;
  }

  &:matches(article, aside, details, figcaption, figure,
  footer, header, hgroup, menu, nav, section) {
    display: block;
  }

  &:matches(ol, ul) {
    list-style: none;
  }

  &:matches(blockquote, q) {
    quotes: none;
  }

  &:matches(blockquote:before, blockquote:after,
  q:before, q:after) {
    content: '';
    content: none;
  }

  &:matches(table) {
    border-collapse: collapse;
    border-spacing: 0;
  }

  &:matches(input,
  textarea) {
    border: none;
    outline: none;
  }

  &:matches(strong), & strong {
    font-weight: 500;
  }

  &:matches(em), & em {
    font-style: italic;
  }
`

const styles = ({
  rounded,
  shadow,
  clearfix,
  backgroundColor,
  circle,
  theme
}) => `
  ${clearfix ? Styles.clearfix() : ''}
  ${shadow ? Styles.shadow(shadow, theme) : ''}
  ${circle ? `border-radius: 9999px` : ''}
  ${backgroundColor ? `background-color: ${backgroundColor};` : ''}
`

const Base = styled(({
  is,
  ...props
}) => React.createElement(is, props))`${baseStyles}`

Base.displayName = 'Base'

Base.propTypes = {
  is: PropTypes.oneOfType([
    PropTypes.string,
    PropTypes.element,
    PropTypes.func // Support StyledComponents
  ])
}

Base.defaultProps = {
  is: 'div'
}

const Box = styled(({
  rounded,
  shadow,
  clearfix,
  backgroundColor,
  circle,
  theme,
  ...props
}) => React.createElement(Base, props))`${styles}`

Box.propTypes = {
  children: PropTypes.any,
  clearfix: PropTypes.bool,
  backgroundColor: PropTypes.string,
  rounded: PropTypes.oneOfType([
    PropTypes.bool,
    PropTypes.oneOf([1, 2, 3])
  ]),
  circle: PropTypes.bool,
  shadow: PropTypes.oneOfType([
    PropTypes.bool,
    PropTypes.oneOf([1, 2])
  ])
}

Box.defaultProps = {
  theme
}

Box.displayName = 'Box'

// Decorate Box with higher order components
export default [
  withSpacing,
  withTextAlign,
  withRounded,
  withTextStyles,
  withFlex,
  withDisplay,
  withPosition,
  withOverflow,
  withDimensions,
  withRotate,
  withTransform,
  withBorders,
  withTruncate
].reduce((comp, hoc) => hoc(comp), Box)
