import Color from 'color'

const rawColors = {
  green900: '#21523A',
  green800: '#2B6B4C',
  green700: '#35855E',
  green600: '#3F9E70',
  green500: '#49B882',
  green400: '#54D194',
  green300: '#84DBB1',
  green200: '#A8F0CD',
  green100: '#CCFFE6',
  green50: '#F2FFF9',

  blue900: '#00386C',
  blue800: '#004585',
  blue700: '#00529E',
  blue600: '#005FB8',
  blue500: '#006CD1',
  blue400: '#1785EB',
  blue300: '#5EA7EB',
  blue200: '#99CEFF',
  blue100: '#C7E4FF',
  blue50: '#F2F9FF',

  peach500: '#FCC79B',
  peach400: '#FAE0CB',

  pink500: '#E365A6',
  pink400: '#FFDAED',

  grey500: '#425E78',
  grey400: '#4B6985',
  grey300: '#7999B8',
  grey200: '#AEC3D6',
  grey100: '#E4EDF5',
  grey50: '#FAFBFC',

  sand: '#FBFAF9',
  white: '#FFFFFF'
}

const fonts = {}

fonts.sans = `'Segment Circular Std', 'Helvetica Neue', Helvetica, Arial, sans-serif`
fonts.serif = `'Segment Aleo', Georgia, serif`
fonts.mono = `'Droid Sans Mono', Monaco, 'Lucida Console', monospace`

const textStyles = {}

textStyles.display1 = {
  fontSize: '22px',
  fontWeight: '400',
  lineHeight: '30px',
  letterSpacing: '-0.67px'
}

textStyles.display2 = {
  fontSize: '20px',
  fontWeight: '400',
  lineHeight: '25px',
  letterSpacing: '-0.645px'
}

textStyles.display3 = {
  fontSize: '18px',
  fontWeight: '400',
  lineHeight: '33px',
  letterSpacing: '-0.31px'
}

textStyles.display4 = {
  fontSize: '16px',
  fontWeight: '500',
  lineHeight: '27px',
  letterSpacing: '0'
}

textStyles.display5 = {
  fontSize: '14px',
  fontWeight: '500',
  lineHeight: '22px',
  letterSpacing: '0'
}

textStyles.body1 = {
  fontSize: '14px',
  fontWeight: '400',
  lineHeight: '22px',
  letterSpacing: '0'
}

textStyles.body2 = {
  fontSize: '12px',
  fontWeight: '400',
  lineHeight: '18px',
  letterSpacing: '0'
}

textStyles.mono = {
  fontSize: '13px',
  fontWeight: '300',
  lineHeight: '21px',
  letterSpacing: '0'
}

textStyles.caps1 = {
  fontSize: '14px',
  fontWeight: '500',
  lineHeight: '21px',
  letterSpacing: '0.1',
  textTransform: 'uppercase'
}

textStyles.caps2 = {
  fontSize: '10px',
  fontWeight: '600',
  lineHeight: '18px',
  letterSpacing: '0.05',
  textTransform: 'uppercase'
}

const colors = {
  dark: [rawColors.blue900],
  darkTint: [rawColors.grey500],
  tint: [rawColors.grey50, rawColors.grey100, rawColors.grey200],
  white: [rawColors.white],
  primary: [rawColors.green500]
}

const intent = {
  primary: {
    default: {
      linkColor: [colors.primary[0]],
      backgroundColor: [colors.primary[0]],
      textColor: [colors.white[0]]
    },
    hover: {
      linkColor: [colors.primary[0]],
      backgroundColor: [rawColors.green400],
      textColor: [colors.white]
    },
    active: {
      linkColor: [colors.primary[0]],
      backgroundColor: [colors.primary[0]],
      textColor: [colors.white]
    },
    focus: {
      linkColor: [colors.primary[0]],
      backgroundColor: [rawColors.green400],
      textColor: [colors.white]
    }
  },
  secondary: {
    default: {
      linkColor: [colors.darkTint[0]],
      backgroundColor: [rawColors.white],
      textColor: [colors.darkTint[0]],
      boxShadow: `inset 0 0 0 1px ${rawColors.grey100}`
    },
    hover: {
      linkColor: [colors.darkTint[0]],
      backgroundColor: [rawColors.white],
      textColor: [colors.dark[0]],
      boxShadow: `inset 0 0 0 1px ${rawColors.green500}`
    },
    active: {
      linkColor: [rawColors.blue500],
      backgroundColor: [colors.tint[0]],
      textColor: [colors.dark[0]],
      boxShadow: `inset 0 0 0 1px ${rawColors.green500}`
    },
    focus: {
      linkColor: [colors.darkTint[0]],
      backgroundColor: [rawColors.white],
      textColor: [colors.dark[0]],
      boxShadow: `inset 0 0 0 1px ${rawColors.green500}`
    }
  },
  danger: {
    default: {
      linkColor: [rawColors.pink500],
      backgroundColor: [rawColors.pink500],
      textColor: [colors.white[0]]
    },
    hover: {
      linkColor: [rawColors.pink500],
      backgroundColor: [Color(rawColors.pink500).whiten(0.3).rgb().string()],
      textColor: [colors.white[0]]
    },
    active: {
      linkColor: [rawColors.pink500],
      backgroundColor: [rawColors.pink500],
      textColor: [colors.white[0]]
    },
    focus: {
      linkColor: [rawColors.pink500],
      backgroundColor: [Color(rawColors.pink500).whiten(0.3).rgb().string()],
      textColor: [colors.white[0]]
    }
  }
}

const context = {}

context.dark = [{
  textColor: [rawColors.white],
  backgroundColor: [rawColors.blue900],
  borderColor: [rawColors.blue800], // TODO: implement/think about dark borderColor
  borderColorInteractive: [colors.primary[0]]
}]

context.white = [{
  textColor: [rawColors.blue900],
  backgroundColor: [rawColors.white],
  borderColor: [rawColors.grey100],
  borderColorInteractive: [colors.primary[0]]
}]

context.tint = [{
  textColor: [rawColors.blue900],
  backgroundColor: [rawColors.grey50],
  borderColor: [rawColors.grey100],
  borderColorInteractive: [colors.primary[0]]
},{
  textColor: [rawColors.blue900],
  backgroundColor: [rawColors.grey100],
  borderColor: [rawColors.grey200],
  borderColorInteractive: [colors.primary[0]]
}]

const space = [
  '0',    // 0
  '4px',  // 1
  '8px',  // 2
  '12px', // 3
  '16px', // 4
  '24px', // 5
  '32px', // 6
  '40px', // 7
  '48px', // 8
  '64px', // 9
  '80px'  // 10
]

const animationEasing = {
  standard: `cubic-bezier(0.4, 0.0, 0.2, 1)`,
  deceleration: `cubic-bezier(0.0, 0.0, 0.2, 1)`,
  acceleration: `cubic-bezier(0.4, 0.0, 1, 1)`,
  sharp: `cubic-bezier(0.4, 0.0, 0.6, 1)`
}

// https://material.io/guidelines/motion/duration-easing.html#duration-easing-common-durations
const animationDuration = {
  faster: `150ms`,
  fast: `225ms`,
  slow: `400ms`
}

const theme = {
  animationEasing,
  animationDuration,
  space,
  rawColors,
  context,
  fonts,
  textStyles,
  colors,
  intent,
  borderRadius: ['5px', '8px'],
  shadows: [
    '0 5px 15px -5px rgba(0,0,0,0.1)',
    '0 2px 4px 0 rgba(0,0,0,0.04)'
  ]
}

export default theme
