import React from 'react';
import { storiesOf, action, linkTo } from '@kadira/storybook'
import {
  App,
  Pane,
  Text,
  Content,
  Link
} from '../components'

const quickBrownFox = 'The quick brown fox jumps over the lazy dog'

export default function paneStory (module) {
  storiesOf('Pane', module)
    .add('usage', () => (
      <App>
        <Pane white padding={10}>
          <Content markdown>
{`
# Pane

The Pane component is the base component to build layouts. Implements \`<Box />\`.

* Pane is almost the same as a Box, but is opiniated for backgrounds/layouts.
* Implement Box instead of Pane if you need Box API's

\`\`\`
<Pane dark padding>
  <Text>${quickBrownFox}</Text>
</Pane>
\`\`\`

`}
          </Content>
          <Pane dark padding>
            <Text>{quickBrownFox}</Text>
          </Pane>
          <Content markdown>
{`

prop | type | description
-----|------|------------
\`dark\`    | boolean | dark background
\`white\`   | boolean  | white background
\`tint\` | boolean/1..2 | tinted background, tint={2} is darker
\`interactive\` | boolean | adds a border color on hover and active

`}
          </Content>
        </Pane>
      </App>
    ))
    .add('is a clickable card', () => (
      <App>
        <Pane is={Link} href='#' margin interactive border white rounded shadow padding><Text>{quickBrownFox}</Text></Pane>
      </App>
    ))
    .add('with dark background', () => (
      <App><Pane dark padding clearfix><Text>{quickBrownFox}</Text></Pane></App>
    ))
    .add('with tint background', () => (
      <App>
        <Pane dark padding>
          <Pane tint margin padding clearfix>Tint (1)</Pane>
          <Pane tint={2} margin padding clearfix>Tint 2</Pane>
        </Pane>
      </App>
    ))
    .add('with white background', () => (
      <App>
        <Pane dark padding>
          <Pane white margin padding clearfix>White</Pane>
        </Pane>
      </App>
    ))
    .add('with padding', () => (
      <App>
        <Pane dark padding>
          <Text display textAlign='center'>Padding</Text>
          {[0,1,2,3,4,5,6,7,8,9,10].map(step =>
            <Pane key={step} white rounded margin padding={step}>Padding {step} {step === 4 && '(default)'}</Pane>
          )}
          <Text display textAlign='center'>Padding Left</Text>
          {[0,1,2,3,4,5,6,7,8,9,10].map(step =>
            <Pane key={step} white rounded margin paddingLeft={step}>Padding Left {step} {step === 4 && '(default)'}</Pane>
          )}
          <Text display textAlign='center'>Padding Top</Text>
          {[0,1,2,3,4,5,6,7,8,9,10].map(step =>
            <Pane key={step} white rounded margin paddingTop={step}>Padding Top {step} {step === 4 && '(default)'}</Pane>
          )}
          <Text display textAlign='center'>Padding Right</Text>
          {[0,1,2,3,4,5,6,7,8,9,10].map(step =>
            <Pane key={step} white rounded margin paddingRight={step} textAlign='center'>Padding Right {step} {step === 4 && '(default)'}</Pane>
          )}
        </Pane>
      </App>
    ))
    .add('with margin', () => (
      <App>
        <Pane dark padding>
          <Text display textAlign='center'>Margin</Text>
          {[0,1,2,3,4,5,6,7,8,9,10].map(step =>
            <Pane key={step} white rounded padding margin={step}>Margin {step} {step === 4 && '(default)'}</Pane>
          )}
          <Text display textAlign='center'>Margin Left</Text>
          {[0,1,2,3,4,5,6,7,8,9,10].map(step =>
            <Pane key={step} white rounded padding marginLeft={step}>Margin Left {step} {step === 4 && '(default)'}</Pane>
          )}
          <Text display textAlign='center'>Margin Top</Text>
          {[0,1,2,3,4,5,6,7,8,9,10].map(step =>
            <Pane key={step} white rounded padding marginTop={step}>Margin Top {step} {step === 4 && '(default)'}</Pane>
          )}
          <Text display textAlign='center'>Margin Right</Text>
          {[0,1,2,3,4,5,6,7,8,9,10].map(step =>
            <Pane key={step} white rounded padding marginRight={step} textAlign='center'>Margin Right {step} {step === 4 && '(default)'}</Pane>
          )}
        </Pane>
      </App>
    ))
    .add('with rounded corners', () => (
      <App>
        <Pane dark clearfix>
          <Pane white padding margin rounded>Rounded (1)</Pane>
          <Pane white padding margin rounded={2}>Rounded 2</Pane>
        </Pane>
      </App>
    ))
    .add('with shadow', () => (
      <App>
        <Pane>
          <Pane white padding margin rounded shadow>Shadow (1)</Pane>
          <Pane white padding margin rounded shadow={2}>Shadow 2</Pane>
        </Pane>
      </App>
    ))
    .add('standalone', () => (
      <Pane>
        <Pane white padding margin rounded shadow>Shadow (1)</Pane>
        <Pane white padding margin rounded shadow={2}>Shadow 2</Pane>
      </Pane>
    ))
}
